import 'package:flutter/material.dart';
import 'package:turismo_rural_frontend/core/data/models/attachment.dart';

class BusinessCard extends StatelessWidget {
  final Attachment? imageUrl;
  final String name;
  final String cnpj;
  final Function() onTap;

  const BusinessCard({
    super.key,
    required this.imageUrl,
    required this.name,
    required this.cnpj,
    required this.onTap,
  });

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: onTap,
      child: Card.outlined(
        margin: const EdgeInsets.symmetric(vertical: 8.0, horizontal: 16.0),
        child: Padding(
          padding: const EdgeInsets.all(12.0),
          child: Row(
            children: [
              Container(
                decoration: BoxDecoration(
                  shape: BoxShape.circle,
                  border: Border.all(
                    color: Theme.of(context).primaryColor,
                    width: 2.0,
                  ),
                ),
                child: CircleAvatar(
                  radius: 30.0,
                  backgroundImage: Image.network(imageUrl?.url ?? '').image,
                ),
              ),
              const SizedBox(width: 16.0),
              Expanded(
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    Text(
                      name,
                      style: Theme.of(context).textTheme.titleMedium,
                    ),
                    const SizedBox(height: 8.0),
                    Text(
                      'Cnpj: $cnpj',
                      style: Theme.of(context).textTheme.bodyMedium,
                    ),
                  ],
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
