import 'package:flutter/material.dart';
import 'package:fluttericon/font_awesome_icons.dart';
import 'package:turismo_rural_frontend/core/data/models/spot.dart';

class SpotDetails extends StatelessWidget {
  final Spot spot;

  String _weekdayName(String openingHour) {
    switch (openingHour) {
      case 'monday':
        return 'Segunda-feira';
      case 'tuesday':
        return 'Terça-feira';
      case 'wednesday':
        return 'Quarta-feira';
      case 'thursday':
        return 'Quinta-feira';
      case 'friday':
        return 'Sexta-feira';
      case 'saturday':
        return 'Sábado';
      case 'sunday':
        return 'Domingo';
      case 'holiday':
        return 'Feriados';
      default:
        return '';
    }
  }

  const SpotDetails({super.key, required this.spot});

  @override
  Widget build(BuildContext context) {
    return Container(
      margin: const EdgeInsets.only(top: 16),
      alignment: AlignmentDirectional.bottomStart,
      child: SingleChildScrollView(
        child: Column(
          children: [
            Container(
              alignment: Alignment.topLeft,
              margin: const EdgeInsets.symmetric(horizontal: 24),
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  Row(
                    children: [
                      Container(
                        margin: const EdgeInsets.only(right: 6),
                        child: const Icon(Icons.access_time_outlined),
                      ),
                      Text(
                        "Horário de atendimento",
                        style: Theme.of(context).textTheme.titleLarge,
                      ),
                    ],
                  ),
                  const SizedBox(height: 20),
                  for (final openingHour in spot.openingHours)
                    Text(
                      "${_weekdayName(openingHour.dayOfWeek)}: ${openingHour.openingHour} - ${openingHour.closingHour}",
                      style: Theme.of(context).textTheme.titleMedium,
                    ),
                  const Padding(
                    padding: EdgeInsets.symmetric(vertical: 24),
                    child: Row(
                      mainAxisAlignment: MainAxisAlignment.center,
                      children: [
                        Padding(
                          padding: EdgeInsets.only(
                            left: 10,
                            right: 45,
                          ),
                          child: Icon(
                            FontAwesome.instagram,
                            size: 40,
                          ),
                        ),
                        Padding(
                          padding: EdgeInsets.only(
                            left: 10,
                            right: 10,
                          ),
                          child: Icon(
                            FontAwesome.facebook,
                            size: 40,
                          ),
                        ),
                        Padding(
                          padding: EdgeInsets.only(
                            left: 45,
                            right: 10,
                          ),
                          child: Icon(
                            FontAwesome.whatsapp,
                            size: 40,
                          ),
                        ),
                      ],
                    ),
                  ),
                ],
              ),
            ),
          ],
        ),
      ),
    );
  }
}
